@@ -629,13 +629,13 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                 break;
                 
             case 'edit_multiple_records':
-                if (!empty($_POST['domain_name']) && !empty($_POST['record_name']) && !empty($_POST['record_type']) && !empty($_POST['priorities']) && !empty($_POST['contents']) && $pdns) {
+                if (!empty($_POST['domain_name']) && !empty($_POST['record_name']) && !empty($_POST['record_type']) && !empty($_POST['contents']) && $pdns) {
                     try {
                         $domain_name = trim($_POST['domain_name']);
                         $record_name = trim($_POST['record_name']);
                         $record_type = strtoupper(trim($_POST['record_type']));
                         $ttl = intval($_POST['ttl'] ?? 3600);
-                        $priorities = $_POST['priorities'];
+                        $priorities = $_POST['priorities'] ?? [];
                         $contents = $_POST['contents'];
                         
                         // Validate record type
@@ -662,13 +662,24 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                             break;
                         }
                         
-                        // Prepare record contents with priorities
+                        // Prepare record contents 
                         $record_contents = [];
-                        for ($i = 0; $i < count($priorities); $i++) {
-                            if (!empty($priorities[$i]) && !empty($contents[$i])) {
-                                $priority = intval($priorities[$i]);
-                                $content = trim($contents[$i]);
-                                $record_contents[] = $priority . ' ' . $content;
+                        if ($record_type === 'NS') {
+                            // For NS records, no priorities needed
+                            for ($i = 0; $i < count($contents); $i++) {
+                                if (!empty($contents[$i])) {
+                                    $content = trim($contents[$i]);
+                                    $record_contents[] = $content;
+                                }
+                            }
+                        } else {
+                            // For MX/SRV records, include priorities
+                            for ($i = 0; $i < count($priorities); $i++) {
+                                if (!empty($priorities[$i]) && !empty($contents[$i])) {
+                                    $priority = intval($priorities[$i]);
+                                    $content = trim($contents[$i]);
+                                    $record_contents[] = $priority . ' ' . $content;
+                                }
                             }
                         }
                         
@@ -1398,27 +1409,46 @@ function editMultipleRecords(domainName, recordName, recordType, recordContent,
     document.getElementById('multiple_ttl').value = ttl;
     document.getElementById('multiple_record_name').value = recordName;
     
-    // Clear existing rows and add the current record
+    // Clear existing rows
     const container = document.getElementById('multiple_records_container');
     container.innerHTML = '';
     
-    // Add the current record
-    const newRow = document.createElement('div');
-    newRow.className = 'row mb-2 record-row';
-    newRow.innerHTML = `
-        <div class="col-md-3">
-            <input type="number" class="form-control" name="priorities[]" placeholder="Priority" min="0" max="65535" value="${priority || ''}" required>
-        </div>
-        <div class="col-md-7">
-            <input type="text" class="form-control" name="contents[]" placeholder="Server address" value="${recordContent}" required>
-        </div>
-        <div class="col-md-2">
-            <button type="button" class="btn btn-danger btn-sm" onclick="removeRecordRow(this)">
-                <i class="fa fa-trash"></i>
-            </button>
-        </div>
-    `;
-    container.appendChild(newRow);
+    if (recordType === 'NS') {
+        // For NS records, we need to load ALL existing NS records for this name, not just the clicked one
+        // We'll make an AJAX call to get all NS records, but for now just show the clicked one
+        // TODO: This could be improved by making an AJAX call to get all existing NS records
+        const newRow = document.createElement('div');
+        newRow.className = 'row mb-2 record-row';
+        newRow.innerHTML = `
+            <div class="col-md-10">
+                <input type="text" class="form-control" name="contents[]" placeholder="Name server (e.g., ns1.example.com)" value="${recordContent}" required>
+            </div>
+            <div class="col-md-2">
+                <button type="button" class="btn btn-danger btn-sm" onclick="removeRecordRow(this)">
+                    <i class="fa fa-trash"></i>
+                </button>
+            </div>
+        `;
+        container.appendChild(newRow);
+    } else {
+        // For MX and SRV records, show the single record being edited
+        const newRow = document.createElement('div');
+        newRow.className = 'row mb-2 record-row';
+        newRow.innerHTML = `
+            <div class="col-md-3">
+                <input type="number" class="form-control" name="priorities[]" placeholder="Priority" min="0" max="65535" value="${priority || ''}" required>
+            </div>
+            <div class="col-md-7">
+                <input type="text" class="form-control" name="contents[]" placeholder="Server address" value="${recordContent}" required>
+            </div>
+            <div class="col-md-2">
+                <button type="button" class="btn btn-danger btn-sm" onclick="removeRecordRow(this)">
+                    <i class="fa fa-trash"></i>
+                </button>
+            </div>
+        `;
+        container.appendChild(newRow);
+    }
     
     // Change the form action to edit_multiple_records
     const form = document.querySelector('#multipleRecordsModal form');
@@ -1426,7 +1456,8 @@ function editMultipleRecords(domainName, recordName, recordType, recordContent,
     actionInput.value = 'edit_multiple_records';
     
     // Update modal title and button
-    document.querySelector('#multipleRecordsModal .modal-title').textContent = 'Edit Multiple MX/SRV Records';
+    const modalTitle = recordType === 'NS' ? 'Edit Multiple NS Records' : 'Edit Multiple MX/SRV Records';
+    document.querySelector('#multipleRecordsModal .modal-title').textContent = modalTitle;
     document.querySelector('#multipleRecordsModal .btn-primary').textContent = 'Update Records';
     
     // Show modal
