@@ -901,6 +901,7 @@ document.addEventListener('DOMContentLoaded', function() {
                     installFields.style.display = 'block';
                     importFields.style.display = 'none';
                     submitBtn.innerHTML = '<i class="fa fa-download"></i> Install WordPress';
+                    submitBtn.disabled = false; // Enable the button for installation
                     
                     // Add required attributes back to visible fields
                     installFields.querySelectorAll('input[name="title"], input[name="admin_password"], input[name="admin_email"]').forEach(field => field.setAttribute('required', ''));
@@ -914,6 +915,7 @@ document.addEventListener('DOMContentLoaded', function() {
             })
             .catch(error => {
                 showAlert('danger', 'Error checking WordPress status: ' + error.message);
+                submitBtn.disabled = false; // Enable button on error so user can still try
             });
         } else {
             installFields.style.display = 'none';
@@ -1023,6 +1025,13 @@ document.addEventListener('DOMContentLoaded', function() {
         e.preventDefault();
         console.log('WordPress install/import form submitted');
         
+        const submitBtn = this.querySelector('button[type="submit"]');
+        const originalText = submitBtn.innerHTML;
+        
+        // Immediately show loading state
+        submitBtn.innerHTML = '<i class="fa fa-spinner fa-spin"></i> Processing...';
+        submitBtn.disabled = true;
+        
         const formData = new FormData(this);
         
         // Determine if we're in install or import mode
@@ -1032,18 +1041,15 @@ document.addEventListener('DOMContentLoaded', function() {
         
         console.log('Form mode:', action);
         
-        const submitBtn = this.querySelector('button[type="submit"]');
-        const originalText = submitBtn.innerHTML;
-        
-        // Show specific feedback based on action
+        // Update loading text based on action
         if (action === 'import') {
             submitBtn.innerHTML = '<i class="fa fa-spinner fa-spin"></i> Analyzing WordPress installation...';
             // Show additional feedback message
             showAlert('info', 'Importing WordPress site... This may take a moment while we analyze the existing installation.');
         } else {
             submitBtn.innerHTML = '<i class="fa fa-spinner fa-spin"></i> Installing WordPress...';
+            showAlert('info', 'Installing WordPress... This may take a few minutes to download and configure WordPress.');
         }
-        submitBtn.disabled = true;
         
         fetch('/api/wordpress-ajax.php', {
             method: 'POST',
